@@ -3,8 +3,7 @@
 import os
 import re
 
-from splunk_appinspect.regex_matcher import RegexMatcher
-from splunk_appinspect.regex_matcher import RegexBundle
+from splunk_appinspect.regex_matcher import RegexBundle, RegexMatcher
 
 
 def _is_path_outside_app_container(path, app_name, is_windows):
@@ -51,7 +50,7 @@ def is_manipulation_outside_of_app_container(path, app_name):
 
 
 class AppVersionNumberMatcher(RegexMatcher):
-    """ Splunk App Version Matcher"""
+    """Splunk App Version Matcher"""
 
     def __init__(self):
         version_number_regex_patterns = [
