@@ -6,17 +6,13 @@
 The **app.conf** file located at **default/app.conf** provides key application information and branding. For more, see [app.conf](https://docs.splunk.com/Documentation/Splunk/latest/Admin/Appconf).
 """
 
-# Python Standard Library
 import logging
-import re
 import os
+import re
 
-# Third-Party Libraries
-# N/A
-# Custom Libraries
 import splunk_appinspect
-from splunk_appinspect.splunk import normalizeBoolean
 from splunk_appinspect.app_util import AppVersionNumberMatcher
+from splunk_appinspect.splunk import normalizeBoolean
 from splunk_appinspect.splunk_defined_conf_file_list import SPLUNK_DEFINED_CONFS
 
 report_display_order = 2
@@ -41,22 +37,20 @@ def check_app_version(app, reporter):
                 lineno = config.get_section("launcher").get_option("version").lineno
                 reporter_output = (
                     "Major, minor, build version numbering "
-                    "is required. File: {}, Line: {}."
-                ).format(filename, lineno)
+                    f"is required. File: {filename}, Line: {lineno}."
+                )
                 reporter.fail(reporter_output, filename, lineno)
 
         except splunk_appinspect.configuration_file.NoOptionError:
             lineno = config.get_section("launcher").lineno
             reporter_output = (
                 "No version specified in launcher section "
-                "of app.conf. File: {}, Line: {}."
-            ).format(filename, lineno)
+                f"of app.conf. File: {filename}, Line: {lineno}."
+            )
             reporter.fail(reporter_output, filename, lineno)
 
         except splunk_appinspect.configuration_file.NoSectionError:
-            reporter_output = (
-                "No launcher section found in app.conf. " "File: {}"
-            ).format(filename)
+            reporter_output = f"No launcher section found in app.conf. File: {filename}"
             reporter.fail(reporter_output, file_name=filename)
     else:
         reporter_output = "`default/app.conf` does not exist."
@@ -83,8 +77,8 @@ def check_that_setup_has_not_been_performed(app, reporter):
                     "The app.conf [install] stanza has the"
                     " `is_configured` property set to true."
                     " This property indicates that a setup was already"
-                    " performed. File: {}, Line: {}."
-                ).format(filename, lineno)
+                    f" performed. File: {filename}, Line: {lineno}."
+                )
                 reporter.fail(reporter_output, filename, lineno)
             else:
                 pass  # Pass - The property is true
@@ -112,21 +106,21 @@ def check_for_valid_package_id(app, reporter):
                 lineno = package_configuration_section.get_option("id").lineno
                 if not _is_package_id_valid(package_id):  # with invalid package id
                     reporter_output = (
-                        "The app.conf [package] stanza's has an invalide 'id' property: {}."
+                        f"The app.conf [package] stanza's has an invalide 'id' property: {package_id.value}."
                         " For the `id` property, it must contain only letters, numbers, `.` (dot),"
                         " and `_` (underscore) characters, and can not endwith a dot character."
                         " Besides, some reserved names are prohibited."
                         " See https://docs.splunk.com/Documentation/Splunk/7.3.1/Admin/Appconf for details."
-                        " File: {}, Line: {}."
-                    ).format(package_id.value, filename, lineno)
+                        f" File: {filename}, Line: {lineno}."
+                    )
                     reporter.fail(reporter_output, filename, lineno)
 
                 elif _is_package_id_with_hyphen(package_id):  # with '-' in package id
                     reporter_output = (
-                        "The app.conf [package] stanza's has 'id' property: {},"
+                        f"The app.conf [package] stanza's has 'id' property: {package_id.value},"
                         " while '-' is not recommended. See https://docs.splunk.com/Documentation/Splunk/7.3.1/Admin/Appconf"
-                        " for more details. File: {}, Line: {}."
-                    ).format(package_id.value, filename, lineno)
+                        f" for more details. File: {filename}, Line: {lineno}."
+                    )
                     reporter.warn(reporter_output, filename, lineno)
             else:
                 reporter_output = "No `id` property under `package` section was detected in `default/app.conf`."
@@ -157,8 +151,8 @@ def check_for_invalid_app_names(app, reporter):
                     "For the app.conf [ui] stanza's 'label' attribute,"
                     " names of community-built apps must not start with 'Splunk'."
                     " For example 'Splunk app for Awesome' is inappropriate,"
-                    " but 'Awesome app for Splunk' is OK. File: {}, Line: {}."
-                ).format(filename, lineno)
+                    f" but 'Awesome app for Splunk' is OK. File: {filename}, Line: {lineno}."
+                )
                 reporter.fail(reporter_output, filename, lineno)
         if app_conf.has_option("launcher", "description"):
             name = app_conf.get("launcher", "description")
@@ -170,8 +164,8 @@ def check_for_invalid_app_names(app, reporter):
                     "For the app.conf [launcher] stanza's 'description' attribute,"
                     " apps built by 3rd parties should not have names starting with Splunk."
                     " For example 'Splunk app for Awesome' is inappropriate,"
-                    " but 'Awesome app for Splunk' is OK. File: {}, Line: {}."
-                ).format(filename, lineno)
+                    f" but 'Awesome app for Splunk' is OK. File: {filename}, Line: {lineno}."
+                )
                 reporter.fail(reporter_output, filename, lineno)
     else:
         reporter_output = "`default/app.conf` does not exist."
@@ -218,12 +212,13 @@ def check_no_install_source_checksum(app, reporter):
                             app_conf.get_section("install").get_option(stanza).lineno
                         )
                         reporter_output = (
-                            "For the app.conf [install] stanza's `{}` attribute,"
+                            f"For the app.conf [install] stanza's `{stanza}` attribute,"
                             " it records a checksum of the tarball from which a given app was installed"
                             " or a given app's local configuration was installed."
                             " Splunk Enterprise will automatically populate this value during installation."
-                            " Developers should *not* set this value explicitly within their app! File: {}, Line: {}."
-                        ).format(stanza, filename, lineno)
+                            " Developers should *not* set this value explicitly within their app!"
+                            f" File: {filename}, Line: {lineno}."
+                        )
                         reporter.warn(reporter_output, filename, lineno)
                     else:
                         pass  # Pass - The property is empty.
@@ -239,9 +234,9 @@ def check_no_install_source_checksum(app, reporter):
 @splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.7.2")
 def check_for_trigger_stanza(app, reporter):
-    """ Check that `default/app.conf` doesn't have a `reload.<CONF_FILE>`, where CONF_FILE is
+    """Check that `default/app.conf` doesn't have a `reload.<CONF_FILE>`, where CONF_FILE is
     a non-custom conf. (https://docs.splunk.com/Documentation/Splunk/7.3.0/Admin/Appconf#.5Btriggers.5D)
-     """
+    """
     if app.file_exists("default", "app.conf"):
         filename = os.path.join("default", "app.conf")
         app_conf = app.app_conf()
@@ -260,20 +255,20 @@ def check_for_trigger_stanza(app, reporter):
         for conf_name, lineno in _get_reloaded_splunk_confs(settings):
             if _is_exported(conf_name, conf_permissions):
                 reporter_output = (
-                    "{}.conf is a Splunk defined conf, which should not "
+                    f"{conf_name}.conf is a Splunk defined conf, which should not "
                     "be configured in [trigger] stanza. Per the documentation, "
                     "it should be configured only for custom config file. "
                     "Please remove this line."
-                ).format(conf_name)
+                )
                 reporter.fail(reporter_output, filename, lineno)
             else:
                 reporter_output = (
-                    "{0}.conf is a Splunk defined conf, which should not "
+                    f"{conf_name}.conf is a Splunk defined conf, which should not "
                     "be configured in [trigger] stanza. Per the documentation, "
                     "it should be configured only for custom config file. "
-                    "However, the {0}.conf is not shared with other apps. "
+                    f"However, the {conf_name}.conf is not shared with other apps. "
                     "Suggest to remove this line."
-                ).format(conf_name)
+                )
                 reporter.warn(reporter_output, filename, lineno)
     else:
         reporter_output = "`default/app.conf` does not exist."
@@ -303,9 +298,7 @@ def check_for_valid_ui_label(app, reporter):
     ui_section = app_config.get_section("ui")
     filepath = os.path.join("default", "app.conf")
     if not ui_section.has_option("label"):
-        reporter_output = (
-            "`label` is required in [ui] stanza. File: {}, Line: {}."
-        ).format(filepath, ui_section.lineno)
+        reporter_output = f"`label` is required in [ui] stanza. File: {filepath}, Line: {ui_section.lineno}."
         reporter.warn(reporter_output, filepath, ui_section.lineno)
         return
 
@@ -313,13 +306,13 @@ def check_for_valid_ui_label(app, reporter):
     if len(label_option.value) < 5 or len(label_option.value) > 80:
         reporter_output = (
             "The length of `label` field under [ui] stanza should between"
-            " 5 to 80 characters. File: {}, Line: {}."
-        ).format(filepath, label_option.lineno)
+            f" 5 to 80 characters. File: {filepath}, Line: {label_option.lineno}."
+        )
         reporter.warn(reporter_output, filepath, label_option.lineno)
         return
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "future")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 def check_reload_trigger_for_all_custom_confs(app, reporter):
     """Check that custom conf files have a corresponding reload trigger in app.conf
 
@@ -330,7 +323,7 @@ def check_reload_trigger_for_all_custom_confs(app, reporter):
     # Get all custom confs
     custom_confs = []
     for directory, filename, _ in app.iterate_files(
-            types=[".conf"], basedir=["default", "local"]
+        types=[".conf"], basedir=["default", "local"]
     ):
         if filename not in SPLUNK_DEFINED_CONFS:
             custom_confs.append(filename)
@@ -342,9 +335,11 @@ def check_reload_trigger_for_all_custom_confs(app, reporter):
     # Get the app config
     app_conf = app.app_conf()
     if not app_conf.has_section("triggers"):
-        reporter.warn(f"App contains custom conf(s) {custom_confs} but does not have a [triggers] stanza in app.conf. "
-                      f"Without a reload trigger the app will request a restart on any change to the conf file, "
-                      f"which may be a negative experience for end-users.")
+        reporter.fail(
+            f"App contains custom conf(s) {custom_confs} but does not have a [triggers] stanza in app.conf. "
+            f"Without a reload trigger the app will request a restart on any change to the conf file, "
+            f"which may be a negative experience for end-users."
+        )
         return
 
     # Check that all the custom confs have a reload trigger
@@ -352,9 +347,11 @@ def check_reload_trigger_for_all_custom_confs(app, reporter):
     for custom_conf in custom_confs:
         reload_option_name = f"reload.{os.path.splitext(custom_conf)[0]}"
         if not app_conf.has_option("triggers", reload_option_name):
-            reporter.warn(f"Custom conf file {custom_conf} does not have a reload trigger in app.conf. "
-                          f"Without a reload trigger the app will request a restart on any change to the conf file, "
-                          f"which may be a negative experience for end-users.")
+            reporter.fail(
+                f"Custom conf file {custom_conf} does not have a reload trigger in app.conf. "
+                f"Without a reload trigger the app will request a restart on any change to the conf file, "
+                f"which may be a negative experience for end-users."
+            )
 
 
 def _get_conf_permissions(default_meta):
@@ -376,7 +373,7 @@ def _get_reloaded_splunk_confs(settings):
     for setting in settings:
         if re.match(reload_pattern, setting.name):
             conf_name = re.sub(reload_pattern, "", setting.name)
-            conf_file_name = "{}.conf".format(conf_name)
+            conf_file_name = f"{conf_name}.conf"
             if (
                 conf_file_name in SPLUNK_DEFINED_CONFS
                 and conf_file_name not in splunk_conf_whitelist
@@ -396,8 +393,7 @@ def _is_exported(conf_name, conf_permissions):
 
 
 def _is_package_id_with_hyphen(package_id):
-    """Check that if package id contains '-'
-    """
+    """Check that if package id contains '-'"""
     return "-" in package_id.value
 
 
