@@ -9,8 +9,6 @@ Ensure that `bindDNpassword` is not specified. For more, see [authentication.con
 import logging
 import os
 
-from six import iteritems
-
 import splunk_appinspect
 from splunk_appinspect.splunk import normalizeBoolean
 
@@ -25,7 +23,7 @@ def check_authentication_conf_does_not_have_binddnpassword_property(app, reporte
     """
     config_file_paths = app.get_config_file_paths("authentication.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             authentication_conf_file = app.authentication_conf(dir=directory)
             stanzas_with_bind_dn_password = [
@@ -60,7 +58,7 @@ def check_saml_auth_should_not_turn_off_signed_assertion(app, reporter):
     """Check that saml-* stanzas in `authentication.conf` do not turn off signedAssertion property"""
     config_file_paths = app.get_config_file_paths("authentication.conf")
     if config_file_paths:
-        for directory, _ in iteritems(config_file_paths):
+        for directory, _ in iter(config_file_paths.items()):
             authentication_conf_file = app.authentication_conf(dir=directory)
             has_auth_type = authentication_conf_file.has_option(
                 "authentication", "authType"
@@ -115,7 +113,7 @@ def check_scripted_authentication_has_valid_python_version_property(
 
     config_file_paths = app.get_config_file_paths("authentication.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             authentication_conf_file = app.authentication_conf(dir=directory)
             if (
