@@ -3,8 +3,6 @@
 """
 ### Bias language (static checks)
 """
-
-# Python Standard Libraries
 import logging
 import os.path
 import platform
@@ -24,12 +22,20 @@ def check_for_bias_language(app, reporter):
     else:
         for directory, filename, _ in app.iterate_files():
             file_path = os.path.join(directory, filename)
-            for line_number, line, found, _ in splunk_appinspect.bias.scan_file_for_bias(
-                    app.get_filename(directory, filename)
+            for (
+                line_number,
+                line,
+                found,
+                _,
+            ) in splunk_appinspect.bias.scan_file_for_bias(
+                app.get_filename(directory, filename)
             ):
                 formatted = line.replace(found, "<<<" + found.upper() + ">>>")
                 if len(formatted) > 65:
                     formatted = formatted[:65] + "..."
-                report = "Bias language is found in the app. {0} ({1}:{2}) [{3}]. File: {1}, Line: {2}.".format(
-                        formatted, file_path, line_number, found)
+                report = (
+                    "Bias language is found in the app. "
+                    f"{formatted} ({file_path}:{line_number}) [{found}]. "
+                    f"File: {file_path}, Line: {line_number}."
+                )
                 reporter.warn(report, filename, line_number)
