@@ -9,8 +9,6 @@ import logging
 import os
 import re
 
-import six
-
 import splunk_appinspect
 
 report_display_order = 2
@@ -194,7 +192,7 @@ def check_coldToFrozenScript_has_valid_python_version_property(
                 ):
                     reporter_output = "The python.version of coldToFrozenScript should be explicitly set to python3."
                     reporter.fail(reporter_output, file_path, section.lineno)
-                elif six.PY3:
+                else:
                     target_script = os.path.basename(
                         section.get_option("coldToFrozenScript")
                         .value.strip()
