@@ -7,11 +7,8 @@ Ensure that **/default/limits.conf** file is omitted.
 
 When included in the app, the **limits.conf** file changes the limits that are placed on the system for hardware use and memory consumption, which is a task that should be handled by Splunk administrators and not by Splunk app developers. For more, see [limits.conf](http://docs.splunk.com/Documentation/Splunk/latest/Admin/Limitsconf).
 """
-
-# Python Standard Library
 import os
 
-# Custom Libraries
 import splunk_appinspect
 
 
@@ -26,6 +23,6 @@ def check_limits_conf(app, reporter):
             "Changes to 'limits.conf' are not allowed. Hardware"
             " and memory limits should be left to Splunk"
             " Administrators. Please remove this file."
-            " File: {}"
-        ).format(file_path)
+            f" File: {file_path}"
+        )
         reporter.fail(reporter_output, file_path)
