@@ -4,17 +4,13 @@
 ### Malware, viruses, malicious content, user security standards (static checks)
 """
 
-# Python Standard Libraries
-from builtins import str as text
+import ipaddress
 import logging
 import os.path
-import re
 import platform
-import ipaddress
+import re
+from builtins import str as text
 
-# Third-Party Libraries
-# N/A
-# Custom Libraries
 import splunk_appinspect
 
 logger = logging.getLogger(__name__)
@@ -41,9 +37,7 @@ def check_for_offensive_material(app, reporter):
                 if len(formatted) > 65:
                     formatted = formatted[:65] + "..."
                 reporter.manual_check(
-                    "{0} ({1}:{2}) [{3}]. File: {1}, Line: {2}.".format(
-                        formatted, file_path, lineno, found
-                    ),
+                    f"{formatted} ({file_path}:{lineno}) [{found}]. File: {file_path}, Line: {lineno}.",
                     file_path,
                     lineno,
                 )
@@ -133,5 +127,5 @@ def check_hostnames_and_ips(app, reporter):
                 ip_type = "UNKNOWN"
 
             distinct_ip[filename].add(ip)
-            report = "{} IP {} is found in {}:{}".format(ip_type, ip, filename, lineno)
+            report = f"{ip_type} IP {ip} is found in {filename}:{lineno}"
             reporter.warn(report, filename, lineno)
