@@ -7,8 +7,6 @@ Ensure that the **outputs.conf** file located in the **/default** folder of the
 """
 import os
 
-from six import iteritems
-
 import splunk_appinspect
 from splunk_appinspect.splunk import normalizeBoolean
 
@@ -24,7 +22,7 @@ def check_if_outputs_conf_exists(app, reporter):
         reporter_output = "`outputs.conf` does not exist."
         reporter.not_applicable(reporter_output)
     else:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             outputs_conf = app.outputs_conf(directory)
             section_names = outputs_conf.section_names()
