@@ -11,8 +11,6 @@ import platform
 import re
 import stat
 
-import six
-
 import splunk_appinspect
 import splunk_appinspect.check_routine as check_routine
 
@@ -114,13 +112,10 @@ def check_for_executable_flag(app, reporter):
             if current_file_relative_path in app.info_from_file:
                 file_output = app.info_from_file[current_file_relative_path]
             else:
-                if six.PY2:
-                    file_output = magic.from_file(current_file_full_path)
-                else:
-                    with open(
-                        current_file_full_path, "r", encoding="utf-8", errors="ignore"
-                    ) as f:
-                        file_output = magic.from_buffer(f.read())
+                with open(
+                    current_file_full_path, "r", encoding="utf-8", errors="ignore"
+                ) as f:
+                    file_output = magic.from_buffer(f.read())
             file_output_regex = re.compile(
                 "(.)*executable(.)*", re.DOTALL | re.IGNORECASE | re.MULTILINE
             )
