@@ -16,8 +16,6 @@ and methods= properties.
 import fnmatch
 import os
 
-from six import iteritems
-
 import splunk_appinspect
 
 
@@ -29,7 +27,7 @@ def check_web_conf(app, reporter):
     stanzas, with [expose:*] only containing `pattern=` and `methods=`."""
     config_file_paths = app.get_config_file_paths("web.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             web_conf = app.web_conf(directory)
             for section in web_conf.sections():
@@ -59,7 +57,7 @@ def check_web_conf(app, reporter):
                 elif section.name.startswith("expose:"):
                     # [expose:*] stanzas are allowed
                     # Fail all properties besides `pattern` and `methods`
-                    for key, value in iteritems(section.options):
+                    for key, value in iter(section.options.items()):
                         if key not in ("pattern", "methods"):
                             reporter_output = (
                                 "Only the `pattern` and `methods`"
@@ -115,7 +113,7 @@ def check_web_conf_expose_patterns_have_restmap_matches(app, reporter):
 
     config_file_paths = app.get_config_file_paths("web.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             web_conf = app.web_conf(directory)
             # As needed, gather every restmap.conf match= property value
