@@ -1,21 +1,20 @@
-# Python Standard Libraries
-import os.path
 import inspect
 import logging
+import os.path
 
-# Custom Libraries
-from splunk_appinspect.python_analyzer import ast_analyzer
-from splunk_appinspect.python_analyzer import file_dep_manager
-from splunk_appinspect.python_analyzer import ast_info_store
+from splunk_appinspect.python_analyzer import (
+    ast_analyzer,
+    ast_info_store,
+    file_dep_manager,
+)
 from splunk_appinspect.python_analyzer.trustedlibs.utilities import get_hash_file
 
-
 logger = logging.getLogger(__name__)
 
 
 class Client(object):
     """
-        One app contains one client
+    One app contains one client
     """
 
     def __init__(
@@ -144,22 +143,22 @@ class Client(object):
 
     def get_dependences(self, filepath):
         """
-            return python file's dependency tree
-            eg:
-                       c
-                      /
-                     b
-                    /
-                   a
-            so the result for `a` should be like:
-            {'parents': [
-                          {'parents': [
-                                       {'parents': [],
-                                        'filepath': c filepath}
-                                      ],
-                          'filepath': b filepath}
-                        ],
-             'filepath': a filepath}
+        return python file's dependency tree
+        eg:
+                   c
+                  /
+                 b
+                /
+               a
+        so the result for `a` should be like:
+        {'parents': [
+                      {'parents': [
+                                   {'parents': [],
+                                    'filepath': c filepath}
+                                  ],
+                      'filepath': b filepath}
+                    ],
+         'filepath': a filepath}
         """
         abs_filepath = self._absolutize_filepath(filepath)
         return self.file_dep_manager.get_dependences(abs_filepath)
@@ -222,12 +221,12 @@ class Client(object):
 
     def _process_files(self):
         """
-            Traverse dependency graph in topological order, parse AST-analyzer
-            for all files
+        Traverse dependency graph in topological order, parse AST-analyzer
+        for all files
 
-            If cycle is detected, this function will degrade to for-loop implementation
-            like `for filepath in filepaths:
-                      ast_analyzer = AstAnalyzer(filepath)`
+        If cycle is detected, this function will degrade to for-loop implementation
+        like `for filepath in filepaths:
+                  ast_analyzer = AstAnalyzer(filepath)`
         """
         logger.debug("start file or folder processing")
         for filepath in self.file_dep_manager.iter_files():
@@ -267,9 +266,8 @@ class Client(object):
                 frame = frame.f_back
         assert check_name is not None and check_name.startswith(
             "check_"
-        ), "Appropriate check name should be provided to trustedlib, {} is given".format(
-            check_name
-        )
+        ), f"Appropriate check name should be provided to trustedlib, {check_name} is given"
+
         for filepath in filepaths:
             relative_path = self._relativize_filepath(filepath)
             # if it is a well-formed python file
